=== modified file 'NEWS'
--- NEWS	2006-02-23 15:47:19 +0000
+++ NEWS	2006-02-28 04:31:50 +0000
@@ -76,6 +76,10 @@
       please use 'branch.fetch' or 'repository.fetch' depending on your
       needs. (Robert Collins)
 
+    * deprecated methods now have a 'is_deprecated' flag on them that can
+      be checked, if you need to determine whether a given callable is 
+      deprecated at runtime. (Robert Collins)
+
   TESTING:
 
     * SFTP tests now shortcut the SSH negotiation, reducing test overhead

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2006-02-24 15:17:36 +0000
+++ bzrlib/commands.py	2006-02-28 04:31:50 +0000
@@ -34,15 +34,16 @@
 import errno
 
 import bzrlib
-import bzrlib.trace
-from bzrlib.trace import mutter, note, log_error, warning, be_quiet
 from bzrlib.errors import (BzrError, 
                            BzrCheckError,
                            BzrCommandError,
                            BzrOptionError,
                            NotBranchError)
+from bzrlib.option import Option
 from bzrlib.revisionspec import RevisionSpec
-from bzrlib.option import Option
+from bzrlib.symbol_versioning import *
+import bzrlib.trace
+from bzrlib.trace import mutter, note, log_error, warning, be_quiet
 
 plugin_cmds = {}
 
@@ -207,8 +208,16 @@
             r[o.name] = o
         return r
 
-    def run_argv(self, argv, alias_argv=None):
-        """Parse command line and run."""
+    @deprecated_method(zero_eight)
+    def run_argv(self, argv):
+        """Parse command line and run.
+        
+        See run_argv_aliases for the 0.8 and beyond api.
+        """
+        return self.run_argv_aliases(argv)
+
+    def run_argv_aliases(self, argv, alias_argv=None):
+        """Parse the command line and run with extra aliases in alias_argv."""
         args, opts = parse_args(self, argv, alias_argv)
         if 'help' in opts:  # e.g. bzr add --help
             from bzrlib.help import help_on_command
@@ -584,15 +593,20 @@
     cmd = str(argv.pop(0))
 
     cmd_obj = get_cmd_object(cmd, plugins_override=not opt_builtin)
+    if not getattr(cmd_obj.run_argv, 'is_deprecated', False):
+        run = cmd_obj.run_argv
+        run_argv = [argv]
+    else:
+        run = cmd_obj.run_argv_aliases
+        run_argv = [argv, alias_argv]
 
     try:
         if opt_lsprof:
-            ret = apply_lsprofiled(opt_lsprof_file, cmd_obj.run_argv, argv, 
-                                   alias_argv)
+            ret = apply_lsprofiled(opt_lsprof_file, run, *run_argv)
         elif opt_profile:
-            ret = apply_profiled(cmd_obj.run_argv, argv, alias_argv)
+            ret = apply_profiled(run, *run_argv)
         else:
-            ret = cmd_obj.run_argv(argv, alias_argv)
+            ret = run(*run_argv)
         return ret or 0
     finally:
         # reset, in case we may do other commands later within the same process

=== modified file 'bzrlib/symbol_versioning.py'
--- bzrlib/symbol_versioning.py	2006-01-26 22:39:10 +0000
+++ bzrlib/symbol_versioning.py	2006-02-28 04:31:50 +0000
@@ -139,3 +139,4 @@
                         decorated_callable)
     decorated_callable.__module__ = callable.__module__
     decorated_callable.__name__ = callable.__name__
+    decorated_callable.is_deprecated = True

=== modified file 'bzrlib/tests/test_symbol_versioning.py'
--- bzrlib/tests/test_symbol_versioning.py	2006-01-26 22:39:10 +0000
+++ bzrlib/tests/test_symbol_versioning.py	2006-02-28 04:31:50 +0000
@@ -87,6 +87,7 @@
             self.assertEqualDiff(expected_docstring, deprecated_callable.__doc__)
             self.assertEqualDiff(expected_name, deprecated_callable.__name__)
             self.assertEqualDiff(expected_module, deprecated_callable.__module__)
+            self.assertTrue(deprecated_callable.is_deprecated)
         finally:
             symbol_versioning.set_warning_method(old_warning_method)
     

